function [success] = createCalibrationComponentObjects(this, ComponentName, varargin)
%CREATECALIBRATIONCOMPONENTOBJECTS creates Simulink calibration objects from AUTOSAR Calibration Component.
%
%   createCalibrationComponentObjects(IMPORTEROBJ 'COMPONENTNAME') creates the Simulink 
%   calibration objects to the AUTOSAR Calibration Component described in the XML file
%   imported by the arxml.importer object IMPORTEROBJ.
%
%   Usage:
%      [success] = createCalibrationComponentObjects(importerObj, componentName, varargin)
%
%   Inputs:
%      importerObj:   arxml.importer object
%      componentName: absolute Short-Name path of the CalPrm-Component
%      varargin:      Parameter/Value pairs. Supported parameters are:
%
%         DataDictionary: String specifying a Simulink data dictionary into
%         which to import the Simulink calibration data objects.
%
%   Outputs:
%      success: It is true if this function is successful. Otherwise, 
%               it is false.

%   Copyright 2008-2017 The MathWorks, Inc.
     
% NOTE, when updating the interface of this function (including 
% optional arguments and their possible values), also update the
% corresponding JSON file for tab completion located in
% matlabroot/toolbox/coder/autosar/functionSignatures.json and add
% relevant testing in
% matlabroot/test/toolbox/rtw/targets/AUTOSAR/API/TabCompletion
% this will help ensure keeping tab completion up to date
  
success = false; %#ok
  
% Create an instance of the inputParser class.
argParser = inputParser;   

% Add arguments to the schema
argParser.addRequired('this', @(x) isa(x, class(x)));
argParser.addRequired('ComponentName',@(x) (ischar(x) || isStringScalar(x)));
argParser.addParameter('DataDictionary', '', @(x) (ischar(x)|| isStringScalar(x)));

% parameters that are not intended to be customer visible
argParser.addParameter('CreateSimulinkObject', true, @(x)(islogical(x)||(x==1)||(x==0)));
argParser.addParameter('NameConflictAction', 'overwrite', @(x)any(strcmpi(x,{'overwrite','makenameunique','error'})));

% convert strings to chars
ComponentName = convertStringsToChars(ComponentName);
for ii = 1 : length(varargin)
    if isstring(varargin{ii})
        varargin{ii} = convertStringsToChars(varargin{ii});
    end
end

% Read and validate each argument
argParser.parse(this, ComponentName, varargin{:});

try
    % Check if the DataDictionary exists
    autosar.mm.mm2sl.utils.checkAndCreateDD(argParser.Results.DataDictionary);
    
    % Create the calibration objects
    p_create_calib_component(this, argParser);
catch Me
    %Trim stack to remove internal creation functions
    autosar.mm.util.MessageReporter.throwException(Me);
end
success = true;

% LocalWords:  IMPORTEROBJ COMPONENTNAME makenameunique pathparts JSON json
