function setDependencies(this, aDependencies)
%SETDEPENDENCIES sets the XML file dependencies associated with the 
%   importer object.
%   SETDEPENDENCIES(IMPORTER, DEPENDENCIES) sets the XML file dependencies
%   DEPENDENCIES associated with the arxml.importer object IMPORTER. 
%
%   DEPENDENCIES can be a cell array of strings (for a list of dependencies),
%   a char array (for a single dependency) or the empty array [] (for removing any 
%   dependency). 
% 
%   Note:
%      All Atomic-Software-Components described in the XML file 
%      dependencies are ignored. 

%   Copyright 2007-2017 The MathWorks, Inc.

if iscellstr(aDependencies) || isStringScalar(aDependencies) ||...
        ischar(aDependencies) || isstring(aDependencies) || isempty(aDependencies)
    
    p_setdependencies(this, aDependencies);

else
   autosar.mm.util.MessageReporter.createWarning('RTW:autosar:badImporterDependencies');
end
