function delete(modelName)
% autosar.api.delete deletes the active mapping and AUTOSAR properties
% information for a Simulink model
%
% Examples:
%
% To delete the AUTOSAR properties and mapping for a model
%    autosar.api.delete('rtwdemo_autosar_counter');
%
% See also autosar.api.create

%   Copyright 2017-2018 The MathWorks, Inc.

if nargin > 0
    modelName = convertStringsToChars(modelName);
end

% make sure that model is loaded in memory
systems = find_system('type', 'block_diagram', 'name', modelName);
if isempty(systems)
    DAStudio.error('RTW:autosar:mdlNotLoaded', modelName);
end

% Is it an appropriate target?
isCompliant = strcmp(get_param(modelName,'AutosarCompliant'), 'on');
if ~isCompliant
    DAStudio.error('RTW:autosar:nonAutosarCompliant');
end

% Close the UI before we delete
autosar_ui_close(modelName);

% unmap and delete the mapping. This will dirty the model. The AUTOSAR part
% will be removed from the slx when the model is saved.
try
    [isMapped, mapping] = autosar.api.Utils.isMapped(modelName);
    if isMapped
        mapping.unmap();
        mmgr = get_param(modelName, 'MappingManager');
        mmgr.deleteMapping(mapping);
    end
catch Me
    %Trim stack to suppress internal mapping functions
    autosar.mm.util.MessageReporter.throwException(Me);
end

% Remove PreSave Fcn
modelObj = get_param(modelName,'Object');
if modelObj.hasCallback('PreSave', 'AutosarSaveAsMdl')
    modelObj.removeCallback('PreSave','AutosarSaveAsMdl');
end

% LocalWords:  rtwdemo slx
