function validateModel( mdlName )
% autosar.api.validateModel Validate the Simulink-AUTOSAR mapping and AUTOSAR
% properties for a model.
% 
% autosar.api.validateModel(MDLNAME) validates the Simulink-AUTOSAR mapping and
% AUTOSAR properties for model MDLNAME.
%
% Examples:
%
% To validate a model
%    autosar.api.validateModel('rtwdemo_autosar_counter');
%
% See also autosar.api.getAUTOSARProperties autosar.api.getSimulinkMapping

%   Copyright 2015-2018 The MathWorks, Inc.

% error out for composition models
if nargin > 0
    mdlName = convertStringsToChars(mdlName);
end

if autosar.api.Utils.isMappedToComposition(mdlName)
    DAStudio.error('autosarstandard:api:CompositionValidationNotSupported', mdlName);
end

validator = autosar.validation.Validator();
try
    validator.verify(get_param(mdlName, 'Handle'));
catch Me
    %Trim stack to hide internal verification functions
    autosar.mm.util.MessageReporter.throwException(Me);
end


% LocalWords:  MDLNAME rtwdemo autosarstandard
