classdef DemStorageCondition < autosar.bsw.ServiceImplementation
    % Class to define Dem StorageCondition

    %   Copyright 2017-2018 The MathWorks, Inc.
    properties (Constant)
        FunctionPrototypeMap = containers.Map( autosar.bsw.DemStorageCondition.Operations, ...
            autosar.bsw.DemStorageCondition.FunctionPrototypes );

        FunctionPrototypeWithIdMap = containers.Map( autosar.bsw.DemStorageCondition.Operations, ...
            autosar.bsw.DemStorageCondition.FunctionPrototypesWithEventId );

        InputArgSpecMap = containers.Map( autosar.bsw.DemStorageCondition.Operations, ...
            autosar.bsw.DemStorageCondition.InputArgSpecs );

        OutputArgSpecMap = containers.Map( autosar.bsw.DemStorageCondition.Operations, ...
            autosar.bsw.DemStorageCondition.OutputArgSpecs );
    end

    properties(Constant, Access=private)
        DefaultClientPortName = 'StorageCondition';
        DefaultInterfacePath = '/AUTOSAR/Services/Dem';
        InterfaceName = 'StorageCondition';
        Operations = {
            'SetStorageCondition'
            };

        FunctionPrototypes = {
            'ERR = %s_SetStorageCondition(ConditionFulfilled)'
            };

        FunctionPrototypesWithEventId = {
            'ERR = %s_SetStorageCondition(StorageConditionId, ConditionFulfilled)'
            };

        InputArgSpecs = {
            'autosar.bsw.BasicSoftwareCaller.boolean_spec(true)'
            };

        OutputArgSpecs = {
            'autosar.bsw.BasicSoftwareCaller.uint8_spec(1)'
            };
    end

    methods(Access=public)

        function this = DemStorageCondition()
        end

        function updateFunctionCaller(this, blkPath, portName, operationName)

            functionPrototypeTemplate = this.FunctionPrototypeMap(operationName);
            functionPrototype = sprintf(functionPrototypeTemplate, portName);

            inputArgSpec = this.InputArgSpecMap(operationName);
            outputArgSpec = this.OutputArgSpecMap(operationName);

            set_param(blkPath, 'FunctionPrototype', functionPrototype);
            set_param(blkPath, 'InputArgumentSpecifications', inputArgSpec);
            set_param(blkPath, 'OutputArgumentSpecifications', outputArgSpec);

        end

    end

    methods(Static, Access=public)

        function deepCopyInterface(mdlName, dstInterfacePath) %#ok<INUSD>
            % Copy interface and data types to model

            arxmlPath = fullfile(autosarroot, '+autosar', '+bsw', '+arxml');
            arxmlFiles = {fullfile(arxmlPath, 'AUTOSAR_BaseTypes.arxml')
                fullfile(arxmlPath, 'AUTOSAR_Type.arxml')
                fullfile(arxmlPath, 'AUTOSAR_MOD_PlatformTypes.arxml')
                fullfile(arxmlPath, 'AUTOSAR_Dem.arxml')};

            autosar.bsw.ServiceImplementation.updateReferences(mdlName, arxmlFiles);
        end

        function defaultClientPortName = getDefaultClientPortName()
            defaultClientPortName =  autosar.bsw.DemStorageCondition.DefaultClientPortName;
        end

        function interfaceName = getInterfaceName()
            interfaceName =  autosar.bsw.DemStorageCondition.InterfaceName;
        end

        function operations = getOperations()
            operations =  autosar.bsw.DemStorageCondition.Operations;
        end

        % This block does not expose a Datatype parameter because it does
        % not use any Enum types
        function hastypeParameter = hasDatatypeParameter()
            hastypeParameter = false;
        end

        function dataTypeCallback(~)
        end

        function operationCallback(~)
        end

        function desc = getDescription()
            desc = autosar.bsw.DemDiagnosticInfo.getDescription();
        end

        function type = getType()
            type = 'DiagnosticStorageConditionCaller';
        end

        function blockIconType = getBlockIconType()
            blockIconType = 'DemCaller';
        end
        
        function help = getHelp()
            help = 'helpview(fullfile(docroot,''ecoder'',''helptargets.map''),''autosar_dem_diagnosticmonitor_block'');';
        end

    end

end

% LocalWords:  Prestore Prestored bsw helptargets dem diagnosticmonitor
