classdef FiM_ControlFunctionAvailable < autosar.bsw.ServiceImplementation
    % Class to define Dem FiM_ControlFunctionAvailable

    %   Copyright 2017-2018 The MathWorks, Inc.
    properties (Constant)
        FunctionPrototypeMap = containers.Map( autosar.bsw.FiM_ControlFunctionAvailable.Operations, ...
            autosar.bsw.FiM_ControlFunctionAvailable.FunctionPrototypes );

        FunctionPrototypeWithIdMap = containers.Map( autosar.bsw.FiM_ControlFunctionAvailable.Operations, ...
            autosar.bsw.FiM_ControlFunctionAvailable.FunctionPrototypesWithId );

        InputArgSpecMap = containers.Map( autosar.bsw.FiM_ControlFunctionAvailable.Operations, ...
            autosar.bsw.FiM_ControlFunctionAvailable.InputArgSpecs );

        OutputArgSpecMap = containers.Map( autosar.bsw.FiM_ControlFunctionAvailable.Operations, ...
            autosar.bsw.FiM_ControlFunctionAvailable.OutputArgSpecs );
    end

    properties(Constant, Access=private)
        DefaultClientPortName = 'FiM_ControlFunctionAvailable';
        DefaultInterfacePath = '/AUTOSAR/Services/FiM';
        InterfaceName = 'FiM_ControlFunctionAvailable';
        Operations = {
            'SetFunctionAvailable'
            };

        FunctionPrototypes = {
            'ERR = %s_SetFunctionAvailable(Availability)'
            };

        FunctionPrototypesWithId = {
            'ERR = %s_SetFunctionAvailable(FID, Availability)'
            };

        InputArgSpecs = {
            'autosar.bsw.BasicSoftwareCaller.boolean_spec(true)'
            };

        OutputArgSpecs = {
            'autosar.bsw.BasicSoftwareCaller.uint8_spec(1)'
            };

    end

    methods(Access=public)

        function this = FiM_ControlFunctionAvailable()
        end

        function updateFunctionCaller(this, blkPath, portName, operationName)

            functionPrototypeTemplate = this.FunctionPrototypeMap(operationName);
            functionPrototype = sprintf(functionPrototypeTemplate, portName);

            inputArgSpec = this.InputArgSpecMap(operationName);
            outputArgSpec = this.OutputArgSpecMap(operationName);

            set_param(blkPath, 'FunctionPrototype', functionPrototype);
            set_param(blkPath, 'InputArgumentSpecifications', inputArgSpec);
            set_param(blkPath, 'OutputArgumentSpecifications', outputArgSpec);

        end

    end

    methods(Static, Access=public)

        function deepCopyInterface(mdlName, dstInterfacePath) %#ok<INUSD>
            % Copy interface and data types to model

            arxmlPath = fullfile(autosarroot, '+autosar', '+bsw', '+arxml');
            arxmlFiles = {fullfile(arxmlPath, 'AUTOSAR_BaseTypes.arxml')
                fullfile(arxmlPath, 'AUTOSAR_Type.arxml')
                fullfile(arxmlPath, 'AUTOSAR_MOD_PlatformTypes.arxml')
                fullfile(arxmlPath, 'AUTOSAR_FiM.arxml')};

            autosar.bsw.ServiceImplementation.updateReferences(mdlName, arxmlFiles);
        end

        function defaultClientPortName = getDefaultClientPortName()
            defaultClientPortName =  autosar.bsw.FiM_ControlFunctionAvailable.DefaultClientPortName;
        end

        function interfaceName = getInterfaceName()
            interfaceName =  autosar.bsw.FiM_ControlFunctionAvailable.InterfaceName;
        end

        function operations = getOperations()
            operations =  autosar.bsw.FiM_ControlFunctionAvailable.Operations;
        end

        % This block does not expose a Datatype parameter because it does
        % not use any Enum types
        function hastypeParameter = hasDatatypeParameter()
            hastypeParameter = false;
        end

        function dataTypeCallback(~)
        end

        function operationCallback(~)
        end

        function desc = getDescription()
            desc = autosar.bsw.FiM_FunctionInhibition.getDescription();
        end

        function type = getType()
            type = 'DiagnosticFiM_ControlFunctionAvailableCaller';
        end

        function blockIconType = getBlockIconType()
            blockIconType = 'FiMCaller';
        end
        
        function help = getHelp()
            help = 'helpview(fullfile(docroot,''ecoder'',''helptargets.map''),''autosar_dem_diagnosticmonitor_block'');';
        end

    end

end

% LocalWords:  Prestore Prestored bsw helptargets dem diagnosticmonitor
