classdef NVRAMServiceComponent < handle
% Class to define a Memory Service Component

%   Copyright 2017 The MathWorks, Inc.
    
    methods(Static, Access=public)

        function desc = getDescription()
            desc = 'Configure AUTOSAR NVRAM Services and Runtime Environment (RTE) for emulation.';
        end
        
        function type = getType()
            type = 'NVRAM Service Component';
        end

        function blockIconType = getBlockIconType()
            blockIconType = 'NVRAMService';
        end
        
        function display = getDisplay()
           display = 'disp(''NVRAM Service\n   Component'')'; 
        end
        
        function help = getHelp()
            help = 'helpview(fullfile(docroot,''ecoder'',''helptargets.map''),''autosar_memory_service_block'');';
        end
        
        
        function addBlocks(blkPath)

            % NVM reference implementation
            nvmBlockH = add_block('autosarspkglib_internal/NvM Module', [blkPath, '/NvM'], ... 
                'Position', [255 168 397 213]);

            % Add areas
            add_block('built-in/Area', ...
                [blkPath, '/RTE'], ...
                'Position', [215 09 447 116], ...
                'BackgroundColor', '[0.992,0.937,0.913]');

            add_block('built-in/Area', ...
                [blkPath,'/Basic Software'], ...
                'Position', [215 128 447 253], ...
                'BackgroundColor', '[0.698,0.698,0.698]');
            
            set_param(nvmBlockH, 'MaxBlockId', 'MaxBlockId');
            
        end
        
        function addMaskObjectParameters(maskObject)
            
            maskObject.addParameter('Type', 'edit', ...
                'Name', 'MaxBlockId',...
                'Prompt', 'Max BlockId:', ...
                'Value', '10', ...
                'Tunable','on',...
                'Evaluate','on',...
                'Hidden','off');
            
            maskObject.addParameterConstraint('Name','u16', ...
                'Parameters',{'MaxBlockId'}, ...
                'Rules', { ...
                'Minimum','1', ...
                'Maximum','65535', ...
                'DataType','uint16', ...
                'Dimension',{'scalar'}, ...
                'Sign',{'positive'}, ...
                'Finiteness',{'finite'}, ...
                'Complexity',{'real'}
                });
            
        end
        
    end
    
end

% LocalWords:  helptargets NVM Nv nvm autosarspkglib
