classdef Debug < handle
    % DEBUG provides utility methods for debugging mode
    
    % Copyright 2016-2018 The MathWorks, Inc.
    
    properties(Access = private)
        IsStackTrace;
    end
    
    methods(Access = private)
        function obj = Debug()
            % Non instantiable constructor
            obj.IsStackTrace = false;
        end
    end
    
    methods(Static, Hidden)
        function debugObj = getInstance()
            % GETINSTANCE
            %
            % Singleton pattern. Create unique instances of the Debug
            % Object.
            persistent debugInstance;
            if isempty(debugInstance)
                debugObj = autosar.utils.Debug();
                debugInstance = debugObj;
            else
                debugObj = debugInstance;
            end
        end
    end
    
    methods(Static, Access = public)
        
        function enable()
            % ENABLE
            %
            % Enables full stack trace functionality
            % >> autosar.utils.Debug.enable
            
            debugger = autosar.utils.Debug.getInstance();
            debugger.IsStackTrace = true;
        end
        
        function disable()
            % DISABLE
            %
            % Disables the full stack trace functionality
            % >> autosar.utils.Debug.disable
            
            debugger = autosar.utils.Debug.getInstance();
            debugger.IsStackTrace = false;
        end
        
        function isStackTrace = showStackTrace()
            %SHOWSTACKTRACKE
            %
            % Returns true if the full stack trace functionality is
            % allowed. Otherwise false
            % >> autosar.utils.Debug.showStrackTrace
            
            debugger = autosar.utils.Debug.getInstance();
            isStackTrace = debugger.IsStackTrace;
        end
    end
end

