classdef Workspace
    %WORKSPACE contains functionality related to the management of workspaces
    % (base workspace, SLDD, model workspace)

%   Copyright 2018 The MathWorks, Inc.
    
    methods (Static, Access = public)
        function [varExists, object, isModelWorkspace] = objectExistsInModelScope(modelName, objectName)
            % OBJECTEXISTSINMODELSCOPE - returns true if the specified object
            % exists in either the base workspace, linked data dictionary or
            % the model workspace.
            
            modelWorkSpace = get_param(modelName,'ModelWorkspace');
            
            varExists = false;
            object = [];
            isModelWorkspace = false;
            
            if ~isvarname(objectName)
                % Ignore invalid variable names
                return;
            end
            
            % Model workspace takes precedence over other workspaces
            if ~isempty(modelWorkSpace)
                varExistsInModelWS = modelWorkSpace.hasVariable(objectName)==1;
                if varExistsInModelWS
                    object = modelWorkSpace.getVariable(objectName);
                    isModelWorkspace = true;
                    varExists = true;
                    return;
                end
            end
            
            if existsInGlobalScope(modelName, objectName)
                if ~Simulink.data.isSupportedEnumClass(objectName)
                    % can't evaluate enum class in dictionary
                    object = evalinGlobalScope(modelName, objectName);
                end
                varExists = true;
                return;
            end
        end
    end
end

% LocalWords:  SLDD OBJECTEXISTSINMODELSCOPE
