function [elementPath, elementName] = splitQualifiedName(qualifiedName)
% autosar.utils.splitQualifiedName splits qualified name to path and name
%
%  qualifiedName can be a char, or cell array of char.
%
%  Example:
%   [elementPath, elementName] = autosar.utils.splitQualifiedName('/a/b/c')
%   elementPath =
%        '/a/b'
%   elementName =
%        'c'
%

%   Copyright 2017 The MathWorks, Inc.

assert((ischar(qualifiedName) || isStringScalar(qualifiedName)) || iscell(qualifiedName),...
    'input must be char or cell array of char.');

% convert to cell array if needed
if iscell(qualifiedName)
    qualifiedNames = qualifiedName;
else
    qualifiedNames = cellstr(qualifiedName);
end

% process cell array
nodeNames = cell(1, length(qualifiedNames));
nodePaths = cell(1, length(qualifiedNames));
for idx=1:length(qualifiedNames)
    tokens = arxml.splitAbsolutePath(qualifiedNames{idx});
    nodeNames{idx} = tokens{end};
    nodePath = '';
    for ii = 1:length(tokens)-1
        nodePath = [nodePath, '/', tokens{ii}]; %#ok
    end
    nodePaths{idx} = nodePath;
end

% return results, preserving class of input
if iscell(qualifiedName)
    elementPath = nodePaths;
    elementName = nodeNames;
else
    elementPath = nodePaths{1};
    elementName = nodeNames{1};
end

% LocalWords:  utils
