classdef ConfigSetFinalValidator < autosar.validation.PhasedValidator
% ConfigSetValidator

%   Copyright 2013-2017 The MathWorks, Inc.

    methods (Access=protected)
        
        function verifyFinal(this, hModel)
            % Following depend on engine interface
            this.verifyMultiTaskingMode(hModel);
            this.verifyRootOutPortsNonConstant(hModel);
        end
        
    end
    
    methods (Static, Access=private)
        
        function verifyMultiTaskingMode(hModel)
        % Function: verifyMultiTaskingMode =============================
        % Abstract: [Engine Interface] Verify settings for multitasking model
            
            % Engine interface will implicitly put model into a compiled state for this
            % sample time check. However for performance assert that the model
            % is precompiled.
            assert(autosar.validation.CompiledModelUtils.isCompiled(hModel));
            
            sess = Simulink.CMI.EIAdapter(Simulink.EngineInterfaceVal.embeddedCoder);
            uddobj = get_param(hModel, 'UDDObject');
            singleRate = uddobj.outputFcnHasSinglePeriodicRate();
            delete(sess);
            
            if ~singleRate && ~strcmp(get_param(hModel, 'SolverMode'), 'SingleTasking')
                % Multi-tasking mode
                if ~autosar.api.Utils.isMapped(hModel)
                    DAStudio.error('RTW:autosar:expectAutosarInterface');
                end
                
            end
            
        end

        function verifyRootOutPortsNonConstant(hModel)
        % Function: verifyRootOutPortsNonConstant =============================
        % Abstract: [Compiled] verify root outports are not constant
            
            outpH = find_system(hModel, 'SearchDepth', 1, 'Type', 'block',...
                                'BlockType', 'Outport');

            for i=1:length(outpH)
                outBlk = outpH(i);
                compiledSampleTime = get_param(outBlk, 'CompiledSampleTime');
                if isinf(compiledSampleTime(1)) && isinf(compiledSampleTime(2))
                    msg = DAStudio.message('RTW:autosar:constantRootOutport', ...
                                           getfullname(outBlk));
                    DAStudio.error('RTW:fcnClass:finish',msg);
                end
            end
            
        end
    
    end

end

% LocalWords:  Validator Async async
