classdef InternalTriggerValidator < autosar.validation.PhasedValidator
    % Validation checks for InternalTrigger blocks
    
    %   Copyright 2018 The MathWorks, Inc.
    
    methods (Access=protected)
        function verifyInitial(this, hModel)
            modelName = getfullname(hModel);
            internalTrigBlocks = autosar.blocks.InternalTriggerBlock.findInternalTriggerBlocks(modelName);
            if isempty(internalTrigBlocks)
                return
            end
            
            this.verifyAR4Schema(modelName, internalTrigBlocks);
            this.verifyExportFunctionModel(modelName, internalTrigBlocks);
            this.verifyCallingContext(modelName);
        end
    end
    
    methods (Static, Access=private)
        function verifyAR4Schema(modelName, internalTrigBlocks)
            % InternalTrigger blocks are only allowed in AR4 schema model
            if ~AR4.isCompatibleSchemaVer(get_param(modelName, 'AutosarSchemaVersion'))
                DAStudio.error('autosarstandard:validation:InternalTriggerBlockOnlyAllowedForAR4Schema', ...
                    getfullname(internalTrigBlocks{1}));
            end
        end
        
        function verifyExportFunctionModel(modelName, internalTrigBlocks)
            % InternalTrigger blocks are only allowed in export function
            % model
            if ~autosar.validation.ExportFcnValidator.isExportFcn(modelName)
                DAStudio.error('autosarstandard:validation:InternalTriggerBlockNotInExportFcnModel', ...
                    getfullname(internalTrigBlocks{1}));
            end
        end
        
        function verifyCallingContext(modelName)
            % InternalTrigger blocks are not allowed in IRT blocks
            irtBlocks = [autosar.utils.InitResetTermFcnBlock.findInitFunctionBlocks(modelName)...
                autosar.utils.InitResetTermFcnBlock.findTermFunctionBlocks(modelName)...
                autosar.utils.InitResetTermFcnBlock.findResetFunctionBlocks(modelName)];
            for i = 1:length(irtBlocks)
                irtBlock = irtBlocks{i};
                internalTrigBlocks = autosar.blocks.InternalTriggerBlock.findInternalTriggerBlocks(irtBlock);
                if ~isempty(internalTrigBlocks)
                    DAStudio.error('autosarstandard:validation:InternalTriggerBlockInIRT',...
                        getfullname(internalTrigBlocks{1}), getfullname(irtBlock));
                end
            end
        end
        
    end
end

% LocalWords:  autosarstandard IRT
