classdef PhasedValidator < handle
% PhasedValidator: Template method class to ensure that validation phases are called in order

%   Copyright 2013 The MathWorks, Inc.
    
    methods (Access=public)
        
        function verify(this, varargin)
            % loop through all phases
            this.verifyPhase('Initial', varargin{:});
            this.verifyPhase('PostProp', varargin{:});
            this.verifyPhase('Final', varargin{:});
        end
        
        
        function verifyPhase(this, validationPhase, varargin)
            
            switch validationPhase
              case 'Initial'
                this.verifyInitial(varargin{:});
              case 'PostProp'
                this.verifyPostProp(varargin{:});
              case 'Final'
                this.verifyFinal(varargin{:});
              otherwise
                assert(false, 'Did not recognize phase %s', validationPhase);
            end
            
        end
        
    end
    
    methods (Access=protected)
        
        function verifyInitial(~, varargin)
        % Override to do actual verification in Initial phase
        end
        
        function verifyPostProp(~, varargin)
        % Override to do actual verification in PostProp phase
        end
        
        function verifyFinal(~, varargin)
        % Override to do actual verification in Final phase
        end
        
    end

end
