classdef CodeInfoTypeBuilder < m3i.Visitor
    % CODEINFOTYPEBUILDER
    %
    %   Copyright 2017-2018 The MathWorks, Inc.
    properties (Access = private)
        CodeInfo;       % The CodeInfo object to be worked upon
        TypeNameMap;    % Map between type name and handle
        XRelArtifactUtils;
        
        M3iComp;
        App2ImpTypeQNameMap;
    end
    
    properties (Constant, Access = private)
        RTWTypeMap = containers.Map( ...
            legacycode.lct.types.Common.NativeTypes, ...
            legacycode.lct.types.Common.DTNames);
    end
    
    properties (SetAccess = private)
        SystemConstants = {};
    end
    
    methods (Access = private)
        function createApp2ImpTypeQNameMap(obj, lM3iComp)
            % CREATEAPP2IMPTYPEQNAMEMAP
            %
            % This functionality is partially duplicated in both
            % mm2rte.TypeBuilder and mm2Sl.TypeBuilder, but in both of
            % those cases, other things happen inside the loop.
            obj.App2ImpTypeQNameMap = containers.Map;
            m3iDataTypeMappingSeq = M3I.SequenceOfClassObject.make(lM3iComp.rootModel);
            autosar.mm.arxml.Exporter.findByBaseType(...
                m3iDataTypeMappingSeq,...
                lM3iComp.rootModel,...
                'Simulink.metamodel.arplatform.common.DataTypeMappingSet');
            for kOuterMapping = 1:m3iDataTypeMappingSeq.size()
                % populate App2ImpTypeQNameMap
                m3iMapping = m3iDataTypeMappingSeq.at(kOuterMapping);
                m3iMapVec =  m3iMapping.dataTypeMap;
                for kInnerMap = 1:m3iMapVec.size()
                    m3iMap = m3iMapVec.at(kInnerMap);
                    appTypeQName = m3iMap.ApplicationType.qualifiedName;
                    impTypeQName = m3iMap.ImplementationType.qualifiedName;
                    obj.App2ImpTypeQNameMap(appTypeQName) = impTypeQName;
                end
            end
        end
    end
    
    methods (Access = public)
        function obj = CodeInfoTypeBuilder(lCodeInfo, lXRelArtifactUtils, lM3iComp)
            % CODEINFOTYPEBUILDER
            %   Cache handle for CodeInfo being operated upon
            %
            obj.CodeInfo = lCodeInfo;
            obj.TypeNameMap = containers.Map;
            obj.XRelArtifactUtils = lXRelArtifactUtils;
            
            % Register visitor for the AUTOSAR side
            obj.registerVisitor('mmVisit', 'mmVisit');
            
            obj.bind('Simulink.metamodel.types.Matrix', @mmWalkTypeMatrix, 'mmVisit');
            obj.bind('Simulink.metamodel.types.FixedPoint', @mmWalkTypeFixPt, 'mmVisit');
            obj.bind('Simulink.metamodel.types.Enumeration', @mmWalkTypeEnum, 'mmVisit');
            obj.bind('Simulink.metamodel.types.Structure', @mmWalkTypeStructure, 'mmVisit');
            obj.bind('Simulink.metamodel.types.StructElement', @mmWalkTypeStructElement, 'mmVisit');
            obj.bind('Simulink.metamodel.types.FloatingPoint', @mmWalkTypeFloat, 'mmVisit');
            obj.bind('Simulink.metamodel.types.Integer', @mmWalkTypeInt, 'mmVisit');
            obj.bind('Simulink.metamodel.types.Boolean', @mmWalkTypeBool, 'mmVisit');
            obj.bind('Simulink.metamodel.types.LookupTableType', @mmWalkTypeLUT, 'mmVisit');
            obj.bind('Simulink.metamodel.types.SharedAxisType', @mmWalkTypeSharedAxis, 'mmVisit');
            
            obj.M3iComp = lM3iComp;
            obj.createApp2ImpTypeQNameMap(lM3iComp);
            
        end
        
        function lCodeInfoType = processType(obj, m3iType, varargin)
            % PROCESSTYPE
            lParser = inputParser;
            lParser.addParameter('Dimensions', []);
            lParser.parse(varargin{:});
            lCodeInfoType = obj.apply('mmVisit', m3iType, lParser.Results.Dimensions);
        end
        
        function lCodeInfoType = wrapScalarWithMatrix(obj, lCodeInfoBaseType, lBaseM3iName)
            % WRAPSCALARWITHMATRIX
            if ~lCodeInfoBaseType.isMatrix
                % Internal name purely to use as key in containers.Map
                % object.
                lM3iName = sprintf('rt_Array_%s_1_1', lBaseM3iName);
                lCodeInfoType = obj.findTypeByName(lM3iName);
                if isempty(lCodeInfoType)
                    lWrapperTypeName = sprintf('matrix1x1x%s', lCodeInfoBaseType.Name);
                    lCodeInfoType = coder.types.Matrix;
                    lCodeInfoType.Dimensions = [1 1];
                    lCodeInfoType.Identifier = ''; % Expect empty identifier in this case
                    lCodeInfoType.Name = lWrapperTypeName;
                    lCodeInfoType.BaseType = lCodeInfoBaseType;
                    obj.pushType(lCodeInfoType, lM3iName);
                end
            else
                % If we are a matrix, then we might still need to modify
                % what we are doing.
                %
                if numel(lCodeInfoBaseType.Dimensions) < 2
                    % Internal name purely to use as key in containers.Map
                    % object.
                    lBaseHasSymbolic = lCodeInfoBaseType.HasSymbolicDimensions;
                    if lBaseHasSymbolic
                        lDim1AsStr = lCodeInfoBaseType.SymbolicDimensions{1};
                    else
                        lDim1AsStr = sprintf('%d', lCodeInfoBaseType.Dimensions(1));
                    end
                    
                    lM3iName = sprintf('rt_Array_%s_1_%s', lBaseM3iName, lDim1AsStr);
                    lCodeInfoType = obj.findTypeByName(lM3iName);
                    if isempty(lCodeInfoType)
                        lWrapperTypeName = sprintf('matrix1x%dx%s', ...
                            lCodeInfoBaseType.Dimensions(1), ...
                            lCodeInfoBaseType.BaseType.Name);
                        lCodeInfoType = coder.types.Matrix;
                        lCodeInfoType.BaseType = lCodeInfoBaseType.BaseType;
                        lCodeInfoType.Dimensions = [1, lCodeInfoBaseType.Dimensions(1)];
                        
                        if lBaseHasSymbolic
                            lCodeInfoType.SymbolicDimensions{1} = '1';
                            lCodeInfoType.SymbolicDimensions{2} = lCodeInfoBaseType.SymbolicDimensions{1};
                            lCodeInfoType.SymbolicWidth = lCodeInfoBaseType.SymbolicDimensions{1};
                        end
                        lCodeInfoType.Identifier = ''; % Expect empty identifier in this case
                        lCodeInfoType.Name = lWrapperTypeName;
                        obj.pushType(lCodeInfoType, lM3iName);
                    end
                else
                    lCodeInfoType = lCodeInfoBaseType;
                end
            end
        end
        
        function lCodeInfoType = getBoolean(obj)
            % GETBOOLEAN
            lM3iName = 'Boolean';
            lCodeInfoType = obj.findTypeByName(lM3iName);
            if isempty(lCodeInfoType)
                lCodeInfoType = coder.types.Bool;
                lCodeInfoType.Identifier = 'boolean_T';
                lCodeInfoType.Name = 'logical';
                obj.pushType(lCodeInfoType, lM3iName);
            end
        end
        
        function lCodeInfoType = getUInt8(obj)
            % GETUINT8
            lM3iName = 'UInt8';
            lCodeInfoType = obj.findTypeByName(lM3iName);
            if isempty(lCodeInfoType)
                lCodeInfoType = coder.types.Int;
                lCodeInfoType.Signedness = false;
                lCodeInfoType.WordLength = 8;
                lCodeInfoType.Identifier = 'uint8_T';
                lCodeInfoType.Name = 'uint8';
                obj.pushType(lCodeInfoType, lM3iName);
            end
        end

        function lCodeInfoType = getUInt32(obj)
            % GETUINT32
            lM3iName = 'UInt32';
            lCodeInfoType = obj.findTypeByName(lM3iName);
            if isempty(lCodeInfoType)
                lCodeInfoType = coder.types.Int;
                lCodeInfoType.Signedness = false;
                lCodeInfoType.WordLength = 32;
                lCodeInfoType.Identifier = 'uint32_T';
                lCodeInfoType.Name = 'uint32';
                obj.pushType(lCodeInfoType, lM3iName);
            end
        end
        
        
        function lCodeInfoType = getRTEInstance(obj)
            % GETRTEINSTANCE
            lM3iName = 'Rte_Instance';
            lCodeInfoType = obj.findTypeByName(lM3iName);
            if isempty(lCodeInfoType)
                lCodeInfoType = coder.types.Opaque;
                lCodeInfoType.Identifier = 'Rte_Instance';
                obj.pushType(lCodeInfoType, lM3iName);
            end
        end
        
        function lCodeInfoType = getStatesType(obj, lIdentifier, lTag)
            % GETSTATESTYPE
            lM3iName = lIdentifier;
            lCodeInfoType = obj.findTypeByName(lM3iName);
            if isempty(lCodeInfoType)
                lCodeInfoType = coder.types.Opaque;
                lCodeInfoType.Identifier = lIdentifier;
                lCodeInfoType.Name = lTag;
                obj.pushType(lCodeInfoType, lM3iName);
            end
        end
        
        function lCodeInfoType = getTypeFromArtifact(obj, lName, lDim)
            % GETTYPEFROMARTIFACT
            %   
            if numel(lDim) > 1 || lDim > 1
                % Need to create matrix object
                dimsAsCellStr = arrayfun(@num2str, lDim, 'UniformOutput', false);
                lnxnString = strjoin(dimsAsCellStr, 'x');
                lMatrixName = sprintf('matrix%sx%s', lnxnString, lName);
                lCodeInfoType = obj.findTypeByName(lName);
                if ~isempty(lCodeInfoType)
                    return;
                end
                lCodeInfoType = coder.types.Matrix;
                lCodeInfoType.Name = lMatrixName;
                lCodeInfoType.Dimensions = lDim;
                lCodeInfoType.BaseType = obj.getTypeFromArtifact(lName, 1);
                obj.pushType(lCodeInfoType, lMatrixName);
                return;
            end    
          
            
            lCodeInfoType = obj.findTypeByName(lName);
            if ~isempty(lCodeInfoType)
                return;
            end
            switch lName
                case 'double'
                    lCodeInfoType = coder.types.Double;
                    lCodeInfoType.Name = 'double';
                    lCodeInfoType.Identifier = 'real_T';
                case 'single'
                    lCodeInfoType = coder.types.Single;
                    lCodeInfoType.Name = 'single';
                    lCodeInfoType.Identifier = 'real32_T';
                case 'uint8'
                    lCodeInfoType = coder.types.Int;
                    lCodeInfoType.Signedness = false;
                    lCodeInfoType.WordLength = 8;
                    lCodeInfoType.Name = 'uint8';
                    lCodeInfoType.Identifier = 'uint8_T';
                case 'int8'
                    lCodeInfoType = coder.types.Int;
                    lCodeInfoType.Signedness = true;
                    lCodeInfoType.WordLength = 8;
                    lCodeInfoType.Name = 'int8';
                    lCodeInfoType.Identifier = 'int8_T';
                case 'uint16'
                    lCodeInfoType = coder.types.Int;
                    lCodeInfoType.Signedness = false;
                    lCodeInfoType.WordLength = 16;
                    lCodeInfoType.Name = 'uint16';
                    lCodeInfoType.Identifier = 'uint16_T';
                case 'int16'
                    lCodeInfoType = coder.types.Int;
                    lCodeInfoType.Signedness = true;
                    lCodeInfoType.WordLength = 16;
                    lCodeInfoType.Name = 'int16';
                    lCodeInfoType.Identifier = 'int16_T';
                case 'uint32'
                    lCodeInfoType = coder.types.Int;
                    lCodeInfoType.Signedness = false;
                    lCodeInfoType.WordLength = 32;
                    lCodeInfoType.Name = 'uint32';
                    lCodeInfoType.Identifier = 'uint32_T';
                case 'int32'
                    lCodeInfoType = coder.types.Int;
                    lCodeInfoType.Signedness = true;
                    lCodeInfoType.WordLength = 32;
                    lCodeInfoType.Name = 'int32';
                    lCodeInfoType.Identifier = 'int32_T';
                case 'boolean'
                    lCodeInfoType = coder.types.Bool;
                    lCodeInfoType.Name = 'logical';
                    lCodeInfoType.Identifier = 'boolean_T';
                otherwise
                    % 
                    [lArtifactTypeInfo, isAlias, isFix, isStruct, isEnum] = obj.XRelArtifactUtils.getTypeByName(lName);
                    if isAlias
                        lOrigCodeInfoType = obj.getTypeFromArtifact(lArtifactTypeInfo.StorageType, 1);
                        % coder.types.Type does not have copy semantics
                        if isa(lOrigCodeInfoType, 'coder.types.Bool')
                            lCodeInfoType = coder.Types.Bool;
                        elseif isa(lOrigCodeInfoType, 'coder.types.Int')
                            lCodeInfoType = coder.types.Int;
                            lCodeInfoType.Signedness = lOrigCodeInfoType.Signedness;
                            lCodeInfoType.WordLength = lOrigCodeInfoType.WordLength;
                        elseif isa(lOrigCodeInfoType, 'coder.types.Double')
                            lCodeInfoType = coder.types.Double;
                        elseif isa(lOrigCodeInfoType, 'coder.types.Single')
                            lCodeInfoType = coder.types.Single;
                        else
                            assert(false, 'Unrecognised type object %s', class(lOrigCodeInfoType));
                        end
                        lCodeInfoType.Name = lName;
                        lCodeInfoType.Identifier = lName;
                    elseif isFix
                        lEmbeddedType = eval(lArtifactTypeInfo.StringReadyForEval);
                        lCodeInfoType = coder.types.Fixed;
                        lCodeInfoType.Scaling = 'SlopeBias';
                        lCodeInfoType.WordLength = lEmbeddedType.WordLength;
                        lCodeInfoType.FractionLength = lEmbeddedType.FractionLength;
                        lCodeInfoType.FixedExponent = lEmbeddedType.FixedExponent;
                        lCodeInfoType.Signedness = strcmp(lEmbeddedType.Signedness, 'Signed');
                        lCodeInfoType.Slope = lEmbeddedType.Slope;
                        lCodeInfoType.SlopeAdjustmentFactor = lEmbeddedType.SlopeAdjustmentFactor;
                        lCodeInfoType.Name = lName;
                        lCodeInfoType.Identifier = lName;
                    elseif isStruct
                        lCodeInfoType = coder.types.Struct;
                        lCodeInfoType.Name = lName;
                        lCodeInfoType.Identifier = lName;
                        lElements = lArtifactTypeInfo.Elements;
                        for kElem = 1:numel(lElements)
                            lAggregateElements(kElem) = coder.types.AggregateElement; %#ok<AGROW>
                            lAggregateElements(kElem).Identifier = lElements(kElem).Identifier; %#ok<AGROW>
                            lAggregateElements(kElem).Type = obj.getTypeFromArtifact(lElements(kElem).DataType, lElements(kElem).Dimensions); %#ok<AGROW>
                        end
                        lCodeInfoType.Elements = lAggregateElements;
                    elseif isEnum
                        lCodeInfoType = coder.types.Enum;
                        lCodeInfoType.Name = lName;
                        lCodeInfoType.Identifier = lName;
                        lCodeInfoType.Strings = lArtifactTypeInfo.Strings;
                        lCodeInfoType.Values = int32(lArtifactTypeInfo.Values);
                        lCodeInfoType.DefaultMember = lArtifactTypeInfo.DefaultMember;
                        if ~isempty(lArtifactTypeInfo.StorageType)
                            lCodeInfoType.StorageType = obj.getTypeFromArtifact(lArtifactTypeInfo.StorageType, 1);
                        end
                    end
                    if isempty(lArtifactTypeInfo)
                        assert(false, 'Unsupported type %s for C-typed PIM', lName);
                    end
            end
            obj.pushType(lCodeInfoType, lName);
        end
    end
    
    
    methods (Access = private)
        function lMatrix = mmWalkTypeMatrix(obj, m3iType, lArtifactDimensions)
            % MMWALKTYPEMATRIX
            
            lM3iTypeName = m3iType.Name;
            lM3iDims = obj.getDimensionsFromM3iType(m3iType);
            lM3iSymDims = obj.getSymbolicDimensionsFromM3iType(m3iType);
            
            lHasArtifactDimensions = ~isempty(lArtifactDimensions);
            lHasSymbolicDimensions = ~isempty(lM3iSymDims);
            
            if lHasArtifactDimensions
                lDims = lArtifactDimensions;
            elseif lHasSymbolicDimensions
                % By convention Dimensions is set to inf for variant dimensions
                lDims = inf;   
            else
                lDims = lM3iDims;
            end
            
            if lHasArtifactDimensions && ~lHasSymbolicDimensions
                % For NON-SYMBOLIC dimensions only:
                %
                % If we have some dimension hints that can help un-flatten
                % matrices, then use them.
                %
                % Update the name because there could be a conflict with an
                % existing type.  This is used only for key-value mapping
                % internally
                assert(prod(lM3iDims) == prod(lArtifactDimensions), 'Dimensions hint does not match dimensions from type');
                lTypeName = obj.getKeyMapTypeNameForMatrix(lM3iTypeName, lArtifactDimensions);
            else
                lTypeName = lM3iTypeName;
            end
                
            lMatrix = obj.findTypeByName(lTypeName);
            if ~isempty(lMatrix)
                return;
            end
            lMatrix = coder.types.Matrix;
            
            % Get base type
            lCodeInfoBaseType = obj.processType(m3iType.BaseType);
            lBaseTypeName = lCodeInfoBaseType.Name;
            
            [lnxnxString, lDimCell] = obj.getMatrixDimensionString(lDims);
            
            if lHasSymbolicDimensions
                if lHasArtifactDimensions
                    % Ensure that the number of symbolic dimensions matches
                    % the number of "numeric" dimensions
                    lSymDims = lDimCell;
                    lSymDims(strcmp(lSymDims, 'inf')) = lM3iSymDims;
                else
                    lSymDims = lM3iSymDims;
                end
                lMatrix.SymbolicDimensions = lSymDims;
                lMatrix.SymbolicWidth = lM3iSymDims{1};
            end
            
            lMatrixTypeName = sprintf('%s%s%s', 'matrix', lnxnxString, lBaseTypeName);
            lMatrix.BaseType = lCodeInfoBaseType;
            lMatrix.Dimensions = lDims;
            lMatrix.Name = lMatrixTypeName;
            obj.pushType(lMatrix, lTypeName);
        end
        
        function lStruct = mmWalkTypeStructure(obj, m3iType, lDimensions)
            % MMWALKTYPESTRUCTURE
            assert(isempty(lDimensions) || prod(lDimensions) == 1, 'Only matrices can be non-scalar.')
            lStruct = obj.findTypeByName(m3iType.Name);
            if ~isempty(lStruct)
                return;
            end
            
            lStruct = coder.types.Struct;
            lStruct.Identifier = m3iType.Name;
            lStruct.Name = m3iType.Name;
            lElements = m3iType.Elements;
            obj.applySeq('mmVisit', lElements, lStruct);
            obj.pushType(lStruct, m3iType.Name);
        end
        
        function ret = mmWalkTypeStructElement(obj, m3iStructElement, lCodeInfoStruct)
            % MMWALKTYPESTRUCTELEMENT
            ret = [];
            lAggregateElement = coder.types.AggregateElement;
            lAggregateElement.Identifier = m3iStructElement.Name;
            m3iType = m3iStructElement.Type;
            lTypeName = m3iType.Name;
            lCodeInfoType = obj.findTypeByName(lTypeName);
            if isempty(lCodeInfoType)
                obj.apply('mmVisit', m3iType, []);
            end
            lCodeInfoType = obj.findTypeByName(lTypeName);
            lAggregateElement.Type = lCodeInfoType;
            lOldElements = lCodeInfoStruct.Elements;
            lCodeInfoStruct.Elements = [];
            lCodeInfoStruct.Elements = [lOldElements, lAggregateElement];
        end
        
        function lTypeObj = mmWalkTypeFixPt(obj, m3iType, lDimensions)
            % MMWALKTYPEFIXPT
            assert(isempty(lDimensions) || prod(lDimensions) == 1, 'Only matrices can be non-scalar.')
            lTypeObj = obj.findTypeByName(m3iType.Name);
            if ~isempty(lTypeObj)
                return;
            end
            
            lTypeObj = coder.types.Fixed;
            lTypeObj.Bias = m3iType.Bias;
            
            % Default, as in regular CodeInfo
            lTypeObj.Scaling = 'SlopeBias';
            lTypeObj.SlopeAdjustmentFactor = m3iType.FractionalSlope;
            lTypeObj.Slope = m3iType.FractionalSlope*double(2)^double(lTypeObj.FixedExponent);
            lTypeObj.FractionLength = -m3iType.FractionLength.value; % Opposite convention
            lTypeObj.FixedExponent = m3iType.FractionLength.value;
            lTypeObj.Signedness = m3iType.IsSigned;
            lTypeObj.WordLength = m3iType.Length.value;
            
            lName = m3iType.Name;
            
            % Need to work out if this is a built-in fixed point type
            % Identifier should be the underlying type
            %[~, lBaseIdentifier] = obj.getBaseIntName(m3iType.IsSigned, m3iType.Length.value);
            %lTypeObj.Identifier = lBaseIdentifier;
            
            lTypeObj.Name = lName;
            lTypeObj.Identifier = lName;
            obj.pushType(lTypeObj, lName);
        end
        
        function lTypeObj = mmWalkTypeEnum(obj, m3iType, lDimensions)
            % MMWALKTYPEENUM
            assert(isempty(lDimensions) || prod(lDimensions) == 1, 'Only matrices can be non-scalar.')
            lTypeObj = obj.findTypeByName(m3iType.Name);
            if ~isempty(lTypeObj)
                return;
            end
            
            lTypeObj = coder.types.Enum;
            assert(strcmp(m3iType.Length.unit.toString, 'bit'));
            
            % Sort out the base type
            %
            % This might be empty if it is int32, per CodeInfo rules
            if ~isempty(m3iType.SwBaseType)
                lBaseTypeName = m3iType.SwBaseType.Name;
                lBaseCodeInfoType = obj.findTypeByName(lBaseTypeName);
                if isempty(lBaseCodeInfoType)
                    % In this case, we need to create the base type
                    lBaseCodeInfoType = coder.types.Int;
                    lBaseCodeInfoType.Signedness = m3iType.IsSigned;
                    lBaseCodeInfoType.WordLength = m3iType.Length.value;
                    
                    [lBaseName, lBaseIdentifier] = obj.getBaseIntName(m3iType.IsSigned, m3iType.Length.value);
                    lBaseCodeInfoType.Name = lBaseName;
                    lBaseCodeInfoType.Identifier = lBaseIdentifier;
                end
                lTypeObj.StorageType = lBaseCodeInfoType;
            end
            
            nElem = m3iType.OwnedLiteral.size;
            lStrings = cell(1, nElem);
            lVals = zeros(1, nElem, 'int32');
            for kElem = 1:nElem
                lStrings{kElem} = m3iType.OwnedLiteral.at(kElem).Name;
                lVals(kElem) = int32(m3iType.OwnedLiteral.at(kElem).Value);
            end
            lTypeObj.Strings = lStrings;
            lTypeObj.Values = lVals;
            lDefaultMemberIdx = find(lVals == m3iType.DefaultValue);
            lTypeObj.DefaultMember = lDefaultMemberIdx;
            obj.resolveNameAndAppendToTypes(lTypeObj, m3iType.Name);
        end
        
        function lTypeObj = mmWalkTypeFloat(obj, m3iType, lDimensions)
            % MMWALKTYPEFLOAT
            assert(isempty(lDimensions) || prod(lDimensions) == 1, 'Only matrices can be non-scalar.')
            lTypeObj = obj.findTypeByName(m3iType.Name);
            if ~isempty(lTypeObj)
                return;
            end
            
            switch m3iType.Kind.toString
                case 'IEEE_Double'
                    lTypeObj = coder.types.Double;
                case 'IEEE_Single'
                    lTypeObj = coder.types.Single;
                otherwise
                    error('Unsupported fp type');
            end
            obj.resolveNameAndAppendToTypes(lTypeObj, m3iType.Name);
        end
        
        function lTypeObj = mmWalkTypeInt(obj, m3iType, lDimensions)
            % MMWALKTYPEINT
            assert(isempty(lDimensions) || prod(lDimensions) == 1, 'Only matrices can be non-scalar.')
            lTypeObj = obj.findTypeByName(m3iType.Name);
            if ~isempty(lTypeObj)
                return;
            end
            
            assert(strcmp(m3iType.Length.unit.toString, 'bit'));
            lWordLength = m3iType.Length.value;
            lSignedness = m3iType.IsSigned;
            if ismember(lWordLength, [8, 16, 32])
                % If the integer is a standard length, then encode as a regular
                % int
                lTypeObj = coder.types.Int;
                assert(strcmp(m3iType.Length.unit.toString, 'bit'));
                lTypeObj.Signedness = lSignedness;
                lTypeObj.WordLength = lWordLength;
                obj.resolveNameAndAppendToTypes(lTypeObj, m3iType.Name);
            else
                % If not a standard length, then encode as fixed point.
                lTypeObj = coder.types.Fixed;
                lTypeObj.Bias = 0;
                lTypeObj.Scaling = 'BinaryPoint';
                lTypeObj.Slope = 1;
                lTypeObj.SlopeAdjustmentFactor = 1;
                lTypeObj.FixedExponent = 0;
                lTypeObj.FractionLength = 0;
                lTypeObj.Signedness = lSignedness;
                lTypeObj.WordLength = lWordLength;
                
                [~, lIdentifier] = obj.getBaseIntName(lSignedness, lWordLength);
                lName = m3iType.Name;
                
                lTypeObj.Identifier = lIdentifier;
                lTypeObj.Name = lName;
                obj.pushType(lTypeObj, lName);
            end
            
        end
        
        function lTypeObj = mmWalkTypeBool(obj, m3iType, lDimensions)
            % MMWALKTYPEBOOL
            assert(isempty(lDimensions) || prod(lDimensions) == 1, 'Only matrices can be non-scalar.')
            lTypeObj = obj.findTypeByName(m3iType.Name);
            if ~isempty(lTypeObj)
                return;
            end
            
            lTypeObj = coder.types.Bool;
            obj.resolveNameAndAppendToTypes(lTypeObj, m3iType.Name);
        end
        
        function lTypeObj = mmWalkTypeLUT(obj, m3iType, lDimensions)
            % MMWALKTYPELUT
            %
            % A lookup table should have a struct type underneath
            lImpQName = obj.App2ImpTypeQNameMap(m3iType.qualifiedName);
            m3iModel = obj.M3iComp.rootModel;
            m3iSeq = autosar.mm.Model.findObjectByName(m3iModel, lImpQName);
            if m3iSeq.size() > 0
                m3iImpl = m3iSeq.at(1);
                lTypeObj = obj.apply('mmVisit', m3iImpl, lDimensions);
            else
                assert(false, 'Lookup table without type');
            end
        end

        function lTypeObj = mmWalkTypeSharedAxis(obj, m3iType, ~)
            % MMWALKTYPESHAREDAXIS
            lImpQName = obj.App2ImpTypeQNameMap(m3iType.qualifiedName);
            m3iModel = obj.M3iComp.rootModel;
            m3iSeq = autosar.mm.Model.findObjectByName(m3iModel, lImpQName);
            if m3iSeq.size() > 0
                m3iImpl = m3iSeq.at(1);
                lTypeObj = obj.apply('mmVisit', m3iImpl, []);
            else
                assert(false, 'Axis without type');
            end
        end
        
        function resolveNameAndAppendToTypes(obj, lCodeInfoTypeObj, lM3iTypeName)
            % RESOLVENAMEANDAPPENTOTYPES
            [lIdentifier, lName] = obj.resolveTypeName(lM3iTypeName);
            lCodeInfoTypeObj.Identifier = lIdentifier;
            lCodeInfoTypeObj.Name = lName;
            obj.pushType(lCodeInfoTypeObj, lM3iTypeName);
        end
        
        function [lIdentifier, lName] = resolveTypeName(obj, lM3iTypeName)
            % RESOLVETYPENAME
            [lIdentifier, isRTWType] = autosar.mm.util.BuiltInTypeMapper.getRTWTypeName(lM3iTypeName);
            if isRTWType
                lName = obj.RTWTypeMap(lIdentifier);
                if strcmp(lName, 'boolean')
                    lName = 'logical';
                end
            else
                lName = lIdentifier;
            end
        end

        function pushType(obj, lCodeInfoType, m3iName)
            % PUSHTYPE
            % Search by the original M3i name.
            assert(~obj.TypeNameMap.isKey(m3iName), 'Type already registered');
            obj.TypeNameMap(m3iName) = lCodeInfoType;
            obj.CodeInfo.Types(end+1) = lCodeInfoType;
        end
        
        function lType = findTypeByName(obj, lM3iTypeName)
            % FINDTYPEBYNAME
            if obj.TypeNameMap.isKey(lM3iTypeName)
                lType = obj.TypeNameMap(lM3iTypeName);
            else
                lType = [];
            end
        end
        
        function lSymDims = getSymbolicDimensionsFromM3iType(obj, m3iType)
            % GETSYMBOLICDIMENSIONSFROMM3ITYPE
            nSymDims = m3iType.SymbolicDimensions.size;
            assert(nSymDims <= 1, 'Cannot support matrix symbolic dimensions');
            lSymDims = cell(1, nSymDims);
            for kSymDim = 1:nSymDims
                [lSymDims{kSymDim}, lSystemConstants] = autosar.mm.util.extractSystemConstantExpressionFromM3I(m3iType.SymbolicDimensions.at(kSymDim));
                obj.SystemConstants = [obj.SystemConstants, lSystemConstants];
            end
        end
    end
    
    methods (Static, Access = private)
        function [lName, lIdentifier] = getBaseIntName(lSignedness, lWordLength)
            % GETBASEINTNAME
            lQuantization = [8 16 32 64];
            for kQuant = 1:numel(lQuantization)
                if lWordLength <= lQuantization(kQuant)
                    lWordLength = lQuantization(kQuant);
                    break;
                end
            end
            if lSignedness
                lName = sprintf('int%d', lWordLength);
            else
                lName = sprintf('uint%d', lWordLength);
            end
            lIdentifier = [lName, '_T'];
        end
        
        function lDims = getDimensionsFromM3iType(m3iType)
            % GETDIMENSIONSFROMM3ITYPE
            nDims = m3iType.Dimensions.size;
            lDims = ones(1, nDims);
            for kDim = 1:nDims
                lDims(kDim) = m3iType.Dimensions.at(kDim);
            end
        end
        
        function lTypeName = getKeyMapTypeNameForMatrix(lM3iTypeName, lArtifactDimensions)
            % GETTYPENAMEFORMATRIX
            dimsAsCellStr = arrayfun(@num2str, lArtifactDimensions, 'UniformOutput', false);
            lnxnString = strjoin(dimsAsCellStr, 'x');
            lTypeName = sprintf('%s_dimensions_%s', lM3iTypeName, lnxnString);
        end
        
        function [lnxnxString, lDimCell] = getMatrixDimensionString(lDims)
            % GETMATRIXDIMENSIONSTRING
            % We need to convert each dimension individually, in case it is
            % inf.
            lDimCell = arrayfun(@(x)sprintf('%d', x), lDims, 'UniformOutput', false);
            lDimCell(strcmp(lDimCell, 'Inf')) = {'inf'};
            lnxnxString = sprintf('%sx', lDimCell{:});
        end
    end
end
