classdef BInfoUtils < handle
    % BINFOUTILS
    %
    %   Utilities for interaction with Binfo during the handling of model
    %   reference submodels for cross-release AUTOSAR
    %
    %   Copyright 2017 The MathWorks, Inc.
    methods (Access = public, Static)
        function writeStubBinfoForSubModel(lIsPortableWordSizesEnabled, lModelRefRelativePathToAnchor, ...
                lAnchorDir, lRelModelRefDir, lRelModelRefSimDir)
            % WRITESTUBBINFOFORSUBMODEL
            lBinfo = coder.internal.xrel.AUTOSAR.BInfoUtils.getStubBinfoForSubModel( ...
                lIsPortableWordSizesEnabled, ...
                lModelRefRelativePathToAnchor);
            
            lTmwInternal = fullfile(lAnchorDir, lRelModelRefDir, 'tmwinternal');
            lBinfo.infoStruct.matFileName = fullfile(lRelModelRefDir, 'binfo_mdlref.mat');
            coder.internal.xrel.AUTOSAR.BInfoUtils.writeBinfo(lBinfo, lTmwInternal);
            
            lSimTmwInternal = fullfile(lAnchorDir, lRelModelRefSimDir, 'tmwinternal');
            lBinfo.infoStruct.matFileName = fullfile(lRelModelRefSimDir, 'binfo_mdlref.mat');
            coder.internal.xrel.AUTOSAR.BInfoUtils.writeBinfo(lBinfo, lSimTmwInternal);
        end
        
        function setModelRefs(lModelName, lModelRefNameList, lModelRefRelativeBuildDirList)
            % SETMODELREFS
            if ~isempty(lModelRefNameList)
                lInfoStruct = coder.internal.infoMATFileMgr('loadNoConfigSet', 'binfo', lModelName, 'NONE');
                lInfoStruct.modelRefsAll = lModelRefNameList;
                lInfoStruct.modelRefsBuildDirs = lModelRefRelativeBuildDirList;
                lInfoStruct.modelRefsBuildDirsAll = lModelRefRelativeBuildDirList;
                coder.internal.infoMATFileMgr('save', 'binfo', lModelName, 'NONE', lInfoStruct);
            end
        end
    end
    
    methods (Access = private, Static)
        function writeBinfo(lBinfo, lTmwInternal)
            % WRITEBINFO
            if ~isfolder(lTmwInternal)
                mkdir(lTmwInternal);
            end
            save(fullfile(lTmwInternal, 'binfo_mdlref.mat'), '-struct', 'lBinfo');
        end
        
        function lBinfo = getStubBinfoForSubModel(lIsPortableWordSizesEnabled, lModelRefRelativePathToAnchor)
            % GETSTUBBINFOFORSUBMODEL
            lBinfo = struct('infoStruct', []);
            lBinfo.infoStruct.globalsInfo.GlobalParamInfo.CollapsedTunableList = '';
            lBinfo.infoStruct.globalsInfo.GlobalParamInfo.VarList = '';
            lBinfo.infoStruct.targetLanguage = 'C';
            lBinfo.infoStruct.IsPortableWordSizesEnabled = lIsPortableWordSizesEnabled;
            lBinfo.infoStruct.designDataLocation = '';
            lBinfo.infoStruct.relativePathToAnchor = lModelRefRelativePathToAnchor;
            lBinfo.infoStruct.codeGenerationIdentifier = 0;
            lBinfo.infoStruct.allModelsWithCodeProfiling = {};
            lBinfo.infoStruct.modelRefsAll = {};
            lBinfo.infoStruct.protectedModelRefs = {};
            lBinfo.infoStruct.rebuildChecksums.childModelTargetMD5s = [];
            lBinfo.infoStruct.checkSum = zeros(1,4);
            lBinfo.infoStructConfigSet = [];
        end
    end
end