classdef CTypePimUtils < handle
    % CTYPEPIMUTILS
    % 
    % C-Typed PIMs do not have the full set of typedefs, so we need to
    % splice this information in as external tool info.  We can only do
    % this once we have a built CodeInfo though, since the mechanism we are
    % using relies upon the embedded type objects.
    %
    % For more info, see g1166393, autosar.mm.mm2rte.ASWCBuilder
    % and autosar.mm.sl2mm.ModelBuilder.
    %
    % Copyright 2017-2018 The MathWorks, Inc.
    %
    properties (Access = private)
        SL2MMTypeBuilder;
    end
    
    methods
        function obj = CTypePimUtils(lModelName, ...
                lAutosarSchemaVersion, ...
                lMaxShortNameLength, ...
                lM3iModel, lM3iBehavior)
            % CTYPEPIMUTILS
            dataObj = autosar.api.getAUTOSARProperties(lModelName);
            lXmlOpts.InterfacePackage    = dataObj.get('XmlOptions', 'InterfacePackage');
            lXmlOpts.ComponentName       = dataObj.get('XmlOptions', 'ComponentQualifiedName');
            lXmlOpts.BehaviorName        = dataObj.get('XmlOptions', 'InternalBehaviorQualifiedName');
            lXmlOpts.ImplementationName  = dataObj.get('XmlOptions', 'ImplementationQualifiedName');
            lXmlOpts.DataTypePackage     = dataObj.get('XmlOptions', 'DataTypePackage');
            
            lAppTypeTracker = autosar.mm.sl2mm.ApplicationTypeTracker();
            vppMerger = autosar.mm.util.SequenceMerger(lM3iModel, ...
                lM3iBehavior.variationPointProxy,...
                'Simulink.metamodel.arplatform.variant.VariationPointProxy');
            lIsAR4 = AR4.isCompatibleSchemaVer(lAutosarSchemaVersion);
            args = {lM3iModel, lM3iBehavior, lMaxShortNameLength, ...
                lIsAR4, lModelName, lXmlOpts, vppMerger, lAppTypeTracker};
            obj.SL2MMTypeBuilder = autosar.mm.sl2mm.TypeBuilder(args{:});
            
        end
        
        function processPIM(obj, m3iPIM, lCodeInfo)
            % PROCESSPIM
            %
            % Step 1 - get the graphical name of the PIM
            lName = m3iPIM.Name;
            
            % Step 2
            %   Get the embedded type object
            %
            % Find the data store object in codeInfo
            %
            fh = @(x)strcmp(x.GraphicalName, lName);
            bIsMatch = arrayfun(fh, lCodeInfo.DataStores);
            lDataInterface = lCodeInfo.DataStores(bIsMatch);
            
            % The Reusable Block State DWork is also a PIM, but it is
            % registered as InternalData, not a DataStore, in which
            % case we won't find any PIMs with that name - and the DWork
            % does not need to be processed here.
            if ~isempty(lDataInterface)
                lType = lDataInterface.Type;
                dataTypeObj = lType;
                
                % Step 3:
                %   Register with ARXML_TypePathForCTypedPIM
                lSlAppTypeAttributes = autosar.mm.util.SlAppTypeAttributes;
                m3iType = ...
                    obj.SL2MMTypeBuilder.findOrCreateType(dataTypeObj, ...
                    lSlAppTypeAttributes);
                pimTypePath = autosar.api.Utils.getQualifiedName(m3iType);
                m3iPIM.setExternalToolInfo(M3I.ExternalToolInfo(...
                    'ARXML_TypePathForCTypedPIM', pimTypePath));
            end
        end
    end
end
