#!/bin/bash

# Script for building Simulink generated code on an autosar.org demonstrator
# build platform.

# Copyright 2014-2018 The MathWorks, Inc.

help() {
    echo "Syntax: $0 yocto_root model_source model_name target"
}

create_bb_file() {
    declare model_name=$1 package_name=$2

    bbfile="$yocto_root/$buildenv/workspace/recipes/$package_name/$package_name.bb"

    cat <<EOF > $bbfile
LICENSE = "CLOSED"
LIC_FILES_CHKSUM = ""

inherit cmake

DEPENDS += "boost"
DEPENDS += "vsomeip"
DEPENDS += "ara-com-lib"
DEPENDS += "ara-com-gen"
DEPENDS += "ara-logging"
DEPENDS += "ara-exec-api"

EOF
}

main() {
    declare yocto_root=$1 model_src=$2 model_name=$3 target=$4

    # oe-init-build-env gets unhappy if we leave command line arguments, so
    # we'll get rid of them.
    while (( $# > 0 )); do
        shift
    done

    if [[ -z "$model_name" ]] ||
       [[ -z "$yocto_root" ]] ||
       [[ -z "$model_src" ]] ||
       [[ -z "$target" ]]; then
        help;
        exit 1;
    fi

    # TODO allow customizing build directory?
    buildenv="build"
    cd "$yocto_root"
    . poky/oe-init-build-env "$buildenv"


    package_name=$(echo "$model_name" | tr _ -)

    # TODO handle existing or conflicting module names
    devtool add "$package_name" "$model_src"

    create_bb_file "$model_name" "$package_name"

    devtool build "$package_name"

    # TODO get IP address of demonstrator dynamically
    devtool deploy-target "$package_name" root@192.168.7.2
}

main "$@"
