classdef AUTOSARPortInfoSerializer < coder.internal.xrelexport.PortInfoSerializer
    % AUTOSARPORTINFOSERIALIZER
    %
    % Copyright 2017-2018 The MathWorks, Inc.
    methods
        function obj = AUTOSARPortInfoSerializer(port_list, xrelmsg)
            % AUTOSARPORTINFOSERIALIZER
            %   Use superclass's initializer
            obj = obj@coder.internal.xrelexport.PortInfoSerializer(port_list, xrelmsg);
        end
    end
    
    methods (Access = protected)
        function writeSimulinkFunctions(obj, writer, top_level_struct)
            % WRITESIMULINKFUNCTIONS
            %
            % Override writeSimulinkFunctions for AUTOSAR
            num_simulinkfunctions = obj.PortList.NumSimulinkFunctions;
            for kFcn = 1:num_simulinkfunctions
                lObject = obj.PortList.getSimulinkFunction(kFcn);
                lPrefixStr = sprintf('%s.%s(%u)',  ...
                    top_level_struct, obj.SimulinkFunctionsFieldName, kFcn);
                lFieldList = {'CGFunctionName', 'AUTOSAROperationName', ...
                    'AUTOSARPortName', 'IsCalled', 'IsDefined'};
                for lField = lFieldList
                    writer.wLine('%s.%s = ''%s'';', lPrefixStr, ...
                        lField{:}, lObject.(lField{:}));
                end
                obj.writeSimulinkFunctionArgList(writer, lObject, lPrefixStr, 'FunctionInputs');
                obj.writeSimulinkFunctionArgList(writer, lObject, lPrefixStr, 'FunctionOutputs');
                obj.writeSimulinkFunctionArgList(writer, lObject, lPrefixStr, 'FunctionReturn');
            end
        end
        
        function writeAUTOSARPortInfo(obj, writer, top_level_struct, idx, port, ports_field_name)
            % WRITEAUTOSARPORTINFO
            writer.wLine('%s.%s(%u).AutosarPort = %s;', ...
                    top_level_struct, ports_field_name, idx, obj.escapeGraphicalName(port.AUTOSARPort));
                writer.wLine('%s.%s(%u).AutosarDataElement = %s;', ...
                    top_level_struct, ports_field_name, idx, obj.escapeGraphicalName(port.AUTOSARDataElement));
                writer.wLine('%s.%s(%u).AutosarReceiverPortNumber = ''%s'';', ...
                    top_level_struct, ports_field_name, idx, port.AUTOSARReceiverPortNumber);
                
                if port.IsQueued
                    lIsQueued = 'true';
                else
                    lIsQueued = 'false';
                end
                writer.wLine('%s.%s(%u).IsQueued = %s;', ...
                    top_level_struct, ports_field_name, idx, lIsQueued);
                
                writer.wLine('%s.%s(%u).QueueLength = %d;', ...
                    top_level_struct, ports_field_name, idx, port.QueueLength);
                
                writer.wLine('%s.%s(%u).DataAccessMode = ''%s'';', ...
                    top_level_struct, ports_field_name, idx, port.DataAccessMode);
        end
        
        function writeSimulinkFunctionArgList(obj, writer, lObject, lPrefixStr, lFieldName)
            % WRITESIMULINKFUNCTIONARGLIST
            % Loop factored into separate function to avoid
            % inconsistent use of input/output indices.
            
            if numel(lObject.(lFieldName)) == 0
                % Placeholder if no args
                lEmptyStructString = 'struct(''Name'', {}, ''Dimensions'', {}, ''SymbolicDimensions'', {}, ''SymbolicWidth'', {}, ''ArgIndex'', {})';
                writer.wLine('%s.%s = %s;', lPrefixStr, lFieldName, lEmptyStructString);
            end
            
            for kArg = 1:numel(lObject.(lFieldName))
                obj.writeSimulinkFunctionArg(writer, lPrefixStr, lObject.(lFieldName)(kArg), lFieldName, kArg);
            end
        end
        
        function writeSimulinkFunctionArg(obj, writer, lPrefixStr, lArgInfo, lFieldName, kElem)
            % WRITESIMULINKFUNCTIONARG
            lCurrentField = sprintf('%s.%s(%d)', lPrefixStr, lFieldName, kElem);
            writer.wLine('%s.Name = ''%s'';', ...
                lCurrentField, ...
                lArgInfo.Name);
            writer.wLine('%s.Dimensions = %s;', ...
                lCurrentField, ...
                mat2str(lArgInfo.Dimensions));
            lSymbolicDimensions = obj.locCellOfStringsToString(lArgInfo.SymbolicDimensions);
            writer.wLine('%s.SymbolicDimensions = %s;', ...
                lCurrentField, ...
                lSymbolicDimensions);
            writer.wLine('%s.SymbolicWidth = ''%s'';', ...
                lCurrentField, ...
                lArgInfo.SymbolicWidth);
            writer.wLine('%s.ArgIndex = ''%s'';', ...
                lCurrentField, ...
                lArgInfo.ArgIndex);
        end
    end
    
    methods (Access = private, Static)
        function lStr = locCellOfStringsToString(lCell)
            % LOCCELLOFSTRINGSTOSTRING
            lStr = ['{', ...
                coder.internal.xrelexport.strjoin( strcat('''', lCell, ''''), '; '), ...
                    '}'];
        end
    end
end
