classdef CodeInfoArgumentAutosarData < handle
    % CODEINFOARGUMENTAUTOSARDATA
    %   This class encapsulates AUTOSAR specific information from CodeInfo
    %   for the cross release workflow.
    %
    % Copyright 2017 The MathWorks, Inc.
    %
    properties (SetAccess = private)
        IsAutosarCalibration = false;
        IsAutosarErrorStatus = false;
        IsAutosarIsUpdated = false;
        IsAutosarInterRunnable = false;
        IsAutosarSenderReceiver = false;
        AutosarPort = '';
        AutosarDataElement = '';
        AutosarDataAccessMode = '';
        AutosarReceiverPortNumber = '';
    end
    
    properties (Dependent, SetAccess = private)
        IsQueued;
    end
    
    methods (Access = public)
        function obj = CodeInfoArgumentAutosarData(lImplementation)
            % CODEINFOARGUMENTAUTOSARDATA
            if isempty(lImplementation)
                return;
            end
            obj.IsAutosarCalibration = isa(lImplementation, 'RTW.AutosarCalibration');
            obj.IsAutosarErrorStatus = isa(lImplementation, 'RTW.AutosarErrorStatus');
            obj.IsAutosarIsUpdated   = isa(lImplementation, 'RTW.AutosarIsUpdated');
            obj.IsAutosarInterRunnable = isa(lImplementation, 'RTW.AutosarInterRunnable');
            obj.IsAutosarSenderReceiver = isa(lImplementation, 'RTW.AutosarSenderReceiver');
            
            if obj.IsAutosarCalibration || ...
                    obj.IsAutosarIsUpdated || ...
                    obj.IsAutosarSenderReceiver
                obj.AutosarPort = lImplementation.Port;
            end
            
            if obj.IsAutosarSenderReceiver || obj.IsAutosarIsUpdated
                obj.AutosarDataElement = lImplementation.DataElement;
            elseif obj.IsAutosarCalibration
                obj.AutosarDataElement = lImplementation.ElementName;
            end
            if obj.IsAutosarSenderReceiver || obj.IsAutosarCalibration ...
                    || obj.IsAutosarIsUpdated || obj.IsAutosarInterRunnable ...
                    || obj.IsAutosarErrorStatus
                obj.AutosarDataAccessMode = lImplementation.DataAccessMode;
            end
            
            if obj.IsAutosarErrorStatus
                obj.AutosarReceiverPortNumber = lImplementation.ReceiverPortNumber;
            end
        end
    end
    
    methods
        function isQueued = get.IsQueued(obj)
            % Must use isempty/strfind because contains is not supported in
            % all releases this code must run in.
            isQueued = ~isempty(strfind(obj.AutosarDataAccessMode, 'Queued'));
        end
    end
    
    
end
