% VERSIONINFO Static information collected at build-time to support backporting.
% This class collects information created at build-time to be used when
% running the cross-release export workflow in an older release.
% This includes:
% * version information to detect if the tool is running in an older
%   release;
% * a static table of error messages extracted at build-time from the
%   message catalog.
% 
% This is a build-time generated MATLAB file: do not edit.

% Copyright 2018 The MathWorks, Inc.

classdef (Hidden = true) VersionInfo < handle

    properties (Constant)
        ReservedParamNames = { ...
            'SimulationMode' ...
            'ComponentPath' ...
            'MaskPortLabels' ...
            'IsTopModelPIL' ...
            'CodeDir' ...
            'AnchorDir' ...
            'ConfigName' ...
            'XRelSourceFile' ...
            'XrelIsTopModelCode' ...
            'XrelIsReusable' ...
            'XrelDWorkNames' ...
            'XrelDWorkTypes' ...
            'XrelModelArgs' ...
            'XrelModelArgVals' ...
            'XrelOrderedParamNames' ...
            'XILSFunction' ...
        };
    end % properties

    properties (Access = private)
        Catalog = containers.Map({...
            'DoesNotSupportFunctionCallerArgsWithNonScalarBus' ...
            'DoesNotSupportModelRefCodeVariants' ...
            'DoesNotSupportModelRefTunableParameters' ...
            'DoesNotSupportModelRefVariantParameters' ...
            'DoesNotSupportQueuedErrorStatus' ...
            'DoesNotSupportParameterImportedStorageClass' ...
            'DoesNotSupportMultiDimensionalSymbolicDimensions' ...
            'LookupTablesNotSupportedInR2015aOrEarlier' ...
            'DoesNotSupportResetFunctionWithSideIOInR2016b' ...
            'DoesNotSupportAUTOSARCTypedPerInstanceMemoriesNVRAM' ...
            }, {...
            'Argument ''{0}'' of Simulink function caller for function ''{1}'' specifies a non-scalar bus type ''{2}'' (dimension {3}).  Cross-Release Export does not Simulink Function Callers with non-scalar bus typed input or output arguments.' ...
            'Cross-release export does not support referenced submodels with code variants defined in ''Rte_Cfg.h''.' ...
            'Cross-release export does not support referenced submodels that access tunable calibration parameters through RTE calls.' ...
            'Cross-release export does not support referenced submodels that access ''SystemConstant'' parameters through RTE calls.' ...
            'Cross-release export does not support AUTOSAR models with error status ports that correspond to queued receiver ports.' ...
            'Cross-release export does not support AUTOSAR models with tunable parameters that use imported storage classes.' ...
            'Cross-release export does not support AUTOSAR models with multi-dimensional symbolic dimensions.' ...
            'Cross-release export does not support AUTOSAR models with tunable lookup tables from R2015a or earlier.' ...
            'Cross-release export does not support code generated from AUTOSAR models in R2016b with Reset Function blocks that are directly connected to root input or output ports.' ...
            'Cross-release export does not support AUTOSAR models using C-typed per-instance memory that needs NVRAM access.' ...
            });
    end % properties

    methods (Access = public)

        function message = getMessage(obj, key)
            message = obj.Catalog(key);
        end % function

        function is_backporting = isBackporting(obj)
            product_version = obj.getProductVersion;
            is_backporting = verLessThan(product_version.Name, product_version.Version);
        end % function

        function version = getProductVersion(~)
            version.Name = 'Simulink';
            version.Version = '9.2';
            version.Release = '(R2018b)';
            version.Date = '24-May-2018';
        end % function

    end % methods

end % classdef
